==> Cosmos.uv4.00.tar.gz: KKlib/kpolintp2.f <==
c             test kpolintp2test kpolintp2
c
c      implicit none
c      integer m, n, adj
c      parameter (m = 20, n=20, adj=m+5)
c      real*8 xa(m),  ya(n), za(adj, n), x, y, z, error
c      integer i, j, ma, na
c      ma = 4
c      na = 4
c      do i =1, m
c         xa(i) = i/5.d0
c      enddo
c
c      do j=1, n
c         ya(j) = j/3.d0
c      enddo
c      do i = 1, m
c         do j = 1,  n
c            za(i, j) = exp(xa(i))* sin(ya(j))
c         enddo
c      enddo
c
c      do i=1, m
c         x= xa(i)+.23
c         do  j=1, n
c            y = ya(j) +.2
c            call kpolintp2(xa, 1, 1/5.d0, ya, 1, 1/3.d0,
c     *       za, adj, m, n, ma, na, x, y, z, error)
cc            write(*, *) x, y, exp(x)*sin(y), z, error
c            write(*, *) sngl(x), sngl(y),
c     *       sngl(abs(z-exp(x)*sin(y))/exp(x)*sin(y))
c         enddo
c         write(*,*)
c      enddo
c      end

c       two dimensional interpolation, using kpolintp
c
      subroutine kpolintp2(xa, xstep, dx, ya, ystep, dy,
     *  za, adj, m, n,  ma, na,  x, y, z, error)
c     ********************************************************
c      real*8 xa(xstep, m). input.
c      real*8 ya(ystep, n). input.
c      real*8 dx.           input. if non zero, xa is assumed to be
c                                  equistepd with dx.
c      real*8 dy.           input. the same as dx for y.
c      integer adj.         input. adjustable dim. fo z >= m
c      real*8 za(adj, n). input.  function values at (xa, ya)
c      real*8 x.            input.  
c      real*8 y.            input.  
c      real*8 z.            output. estimated func. value at (x, y).
c
c     integer ma.          input.  a max of ma points around x is used
c     integer na.          input.  a max of na points around y is used.
c                    ma, na <= maxp(=10)
c
      implicit none
      integer xstep, ystep,  n, m, na, ma, adj
      real*8 xa(xstep, m), ya(ystep, n), za(adj, n)
      real*8 x, y, z, error, dx, dy

      integer lx, ly, kx, ky, i, maxp
      parameter (maxp = 10)  ! max # of points. 
      real*8  ztmp(maxp)
c
      if(ma .gt. maxp .or. na .gt. maxp) then
         write(*, *) "kpolintp2: too large number of point"
         stop
      endif

      if(dx .eq. 0.) then
         call kdwhereis(x, m, xa, xstep, lx)
      else
         lx = (x - xa(1,1))/dx+1
      endif

      if(dy .eq. 0.) then
         call kdwhereis(y, n, ya, ystep, ly)
      else
         ly = (y-ya(1,1))/dy +1
      endif

      kx = min(max(lx - (ma -1)/2,1), m+1-ma)   ! max of ma points from kx
      ky = min(max(ly - (na -1)/2,1), n+1-na)   ! max of na points from ky

c         make ztmp: scan along x direction
      do i = kx, min(m, kx + ma-1)
         call kpolintp(ya(1, ky), ystep, za(i, ky), adj, 
     *      min(na, n- ky +1), y, ztmp(i-kx+1), error)
      enddo
      call kpolintp(xa(1, kx), xstep, ztmp,  1, 
     *      min(ma, m-kx +1),  x,  z, error)
      end

==> Cosmos.uv7.32.tar.gz: KKlib/kpolintp2.f <==
c             test kpolintp2test kpolintp2
c
c      implicit none
c      integer m, n, adj
c      parameter (m = 20, n=20, adj=m+5)
c      real*8 xa(m),  ya(n), za(adj, n), x, y, z, error
c      integer i, j, ma, na
c      ma = 4
c      na = 4
c      do i =1, m
c         xa(i) = i/5.d0
c      enddo
c
c      do j=1, n
c         ya(j) = j/3.d0
c      enddo
c      do i = 1, m
c         do j = 1,  n
c            za(i, j) = exp(xa(i))* sin(ya(j))
c         enddo
c      enddo
c
c      do i=1, m
c         x= xa(i)+.23
c         do  j=1, n
c            y = ya(j) +.2
c            call kpolintp2(xa, 1, 1/5.d0, ya, 1, 1/3.d0,
c     *       za, adj, m, n, ma, na, x, y, z, error)
cc            write(*, *) x, y, exp(x)*sin(y), z, error
c            write(*, *) sngl(x), sngl(y),
c     *       sngl(abs(z-exp(x)*sin(y))/exp(x)*sin(y))
c         enddo
c         write(*,*)
c      enddo
c      end

c       two dimensional interpolation, using kpolintp
c
      subroutine kpolintp2(xa, xstep, dx, ya, ystep, dy,
     *  za, adj, m, n,  ma, na,  x, y, z, error)
c     ********************************************************
c      real*8 xa(xstep, m). input.
c      real*8 ya(ystep, n). input.
c      real*8 dx.           input. if non zero, xa is assumed to be
c                                  equistepd with dx.
c      real*8 dy.           input. the same as dx for y.
c      integer adj.         input. adjustable dim. fo z >= m
c      real*8 za(adj, n). input.  function values at (xa, ya)
c      real*8 x.            input.  
c      real*8 y.            input.  
c      real*8 z.            output. estimated func. value at (x, y).
c
c     integer ma.          input.  a max of ma points around x is used
c     integer na.          input.  a max of na points around y is used.
c                    ma, na <= maxp(=10)
c
      implicit none
      integer xstep, ystep,  n, m, na, ma, adj
      real*8 xa(xstep, m), ya(ystep, n), za(adj, n)
      real*8 x, y, z, error, dx, dy

      integer lx, ly, kx, ky, i, maxp
      parameter (maxp = 10)  ! max # of points. 
      real*8  ztmp(maxp)
c
      if(ma .gt. maxp .or. na .gt. maxp) then
         write(*, *) "kpolintp2: too large number of point"
         stop
      endif

      if(dx .eq. 0.) then
         call kdwhereis(x, m, xa, xstep, lx)
      else
         lx = (x - xa(1,1))/dx+1
      endif

      if(dy .eq. 0.) then
         call kdwhereis(y, n, ya, ystep, ly)
      else
         ly = (y-ya(1,1))/dy +1
      endif
      kx = min(max(lx - (ma -1)/2,1), m+1-ma)   ! max of ma points from kx
      ky = min(max(ly - (na -1)/2,1), n+1-na)   ! max of na points from ky

c         make ztmp: scan along x direction
      do i = kx, min(m, kx + ma-1)
         if(dy .eq. 0.) then
            call kpolintp(ya(1, ky), ystep, za(i, ky), adj, 
     *      min(na, n- ky +1), y, ztmp(i-kx+1), error)
         else
            call kpolintpeqs( (ya(1, 1)+(ky-1)*dy), dy, za(i, ky), adj, 
     *      min(na, n- ky +1), y, ztmp(i-kx+1), error)
         endif
      enddo
      if(dx .eq. 0.) then
         call kpolintp(xa(1, kx), xstep, ztmp,  1, 
     *      min(ma, m-kx +1),  x,  z, error)
      else
         call kpolintpeqs( (xa(1, 1)+(kx-1)*dx),  dx, ztmp,  1, 
     *      min(ma, m-kx +1),  x,  z, error)
      endif         
      end
